@@ -1,5 +1,5 @@
 /*
- * dfreq~: cound zero-crossings as a simple fequency estimation
+ * dfreq~: count zero-crossings as a simple frequency estimation
  *
  * (c) 1999-2011 IOhannes m zmölnig, forum::für::umläute, institute of electronic music and acoustics (iem)
  *
@@ -109,7 +109,7 @@ static void dfreq_tilde_helper(void)
 ZEXY_SETUP void dfreq_tilde_setup(void)
 {
   dfreq_class = zexy_new("dfreq~",
-                         dfreq_new, 0, t_dfreq, 0, "");
+                         dfreq_new, 0, t_dfreq, CLASS_DEFAULT, "");
   zexy_addmethod(dfreq_class, (t_method)nullfn, "signal", "");
   zexy_addmethod(dfreq_class, (t_method)dfreq_dsp, "dsp", "!");
 
