@@ -148,7 +148,7 @@ static void *dirac_new(t_floatarg where)
 ZEXY_SETUP void dirac_tilde_setup(void)
 {
   dirac_class = zexy_new("dirac~",
-                         dirac_new, 0, t_dirac, 0, "F");
+                         dirac_new, 0, t_dirac, CLASS_DEFAULT, "F");
   class_addfloat(dirac_class, dirac_float);
   class_addbang(dirac_class, dirac_bang);
   zexy_addmethod(dirac_class, (t_method)dirac_dsp, "dsp", "!");
