@@ -268,7 +268,7 @@ static void *freadln_new(void)
 ZEXY_SETUP void freadln_setup(void)
 {
   freadln_class = zexy_new("freadln",
-                           freadln_new,  freadln_free, t_freadln, 0, "");
+                           freadln_new,  freadln_free, t_freadln, CLASS_DEFAULT, "");
   zexy_addmethod(freadln_class, (t_method)freadln_open, "open", "sS");
   zexy_addmethod(freadln_class, (t_method)freadln_close, "close", "");
   class_addbang(freadln_class, (t_method)freadln_readline);
