@@ -470,24 +470,24 @@ static t_int *oversampling_maxima(t_int *w)
     sinccurrent = SINC[4] * current;
 
     os1= Z_FABS(SINC[0] * last4 +
-               SINC[1] * last3 +
-               SINC[2] * last2 +
-               SINC[3] * last1 +
-               sinccurrent +
-               SINC[5] * next1 +
-               SINC[6] * next2 +
-               SINC[7] * next3 +
-               SINC[8] * next4);
+                SINC[1] * last3 +
+                SINC[2] * last2 +
+                SINC[3] * last1 +
+                sinccurrent +
+                SINC[5] * next1 +
+                SINC[6] * next2 +
+                SINC[7] * next3 +
+                SINC[8] * next4);
 
     os2= Z_FABS(SINC[0] * next4 +
-               SINC[1] * next3 +
-               SINC[2] * next2 +
-               SINC[3] * next1 +
-               sinccurrent +
-               SINC[5] * last1 +
-               SINC[6] * last2 +
-               SINC[7] * last3 +
-               SINC[8] * last4);
+                SINC[1] * next3 +
+                SINC[2] * next2 +
+                SINC[3] * next1 +
+                sinccurrent +
+                SINC[5] * last1 +
+                SINC[6] * last2 +
+                SINC[7] * last3 +
+                SINC[8] * last4);
 
     max = Z_FABS(current);
 
@@ -770,7 +770,7 @@ ZEXY_SETUP void limiter_tilde_setup(void)
   init_sinc();
 
   limiter_class = zexy_new("limiter~",
-                           limiter_new, limiter_free, t_limiter, 0, "*");
+                           limiter_new, limiter_free, t_limiter, CLASS_DEFAULT, "*");
 
   zexy_addmethod(limiter_class, (t_method)nullfn, "signal", "");
   zexy_addmethod(limiter_class, (t_method)limiter_dsp, "dsp", "!");
