@@ -141,7 +141,7 @@ static void list2lists_help(t_list2lists*UNUSED(x))
 ZEXY_SETUP void list2lists_setup(void)
 {
   list2lists_class = zexy_new("list2lists",
-                              list2lists_new, list2lists_free, t_list2lists, 0, "*");
+                              list2lists_new, list2lists_free, t_list2lists, CLASS_DEFAULT, "*");
   class_addlist    (list2lists_class, list2lists_list);
   zexy_addmethod(list2lists_class, (t_method)list2lists_list2, "lst2", "*");
 
