@@ -227,7 +227,7 @@ static void listfind_help(t_listfind*UNUSED(x))
 ZEXY_SETUP void listfind_setup(void)
 {
   listfind_class = zexy_new("listfind",
-                            listfind_new, listfind_free, t_listfind, 0, "*");
+                            listfind_new, listfind_free, t_listfind, CLASS_DEFAULT, "*");
   class_addlist    (listfind_class, listfind_list);
   zexy_addmethod(listfind_class, (t_method)listfind_list2, "lst2", "*");
 
