@@ -133,7 +133,7 @@ static void *step_new(t_floatarg farg)
 ZEXY_SETUP void step_tilde_setup(void)
 {
   step_class = zexy_new("step~",
-                        step_new, 0, t_step, 0, "F");
+                        step_new, 0, t_step, CLASS_DEFAULT, "F");
 
   class_addfloat(step_class, step_float);
   class_addbang(step_class, step_bang);
