@@ -31,7 +31,7 @@
 # define vsnprintf _vsnprintf
 #endif
 
-/* foward declarations */
+/* forward declarations */
 void  z_zexy_setup(void);
 
 /* do a little help thing */
@@ -155,7 +155,7 @@ void zexy_setup(void)
   }
   endpost();
   post("\t"HEARTSYMBOL " the zexy external  "VERSION);
-  post("\t"HEARTSYMBOL " (c) 1999-2012 IOhannes m zmölnig");
+  post("\t"HEARTSYMBOL " (c) 1999-2023 IOhannes m zmölnig");
   post("\t"HEARTSYMBOL "       forum::für::umläute");
   post("\t"HEARTSYMBOL "       iem  @  kug");
   post("\t"HEARTSYMBOL "  compiled  "BUILD_DATE);
@@ -168,7 +168,7 @@ void zexy_setup(void)
   endpost();
 
   zexy_class = zexy_new("zexy",
-                        zexy_ctor, 0, t_zexy, 0, "");
+                        zexy_ctor, 0, t_zexy, CLASS_DEFAULT, "");
   zexy_addmethod(zexy_class, (t_method)zexy_help, "help", "");
 
   zexy_register("zexy");
