@@ -109,7 +109,8 @@ static void *zNdelay_new(t_symbol*UNUSED(s), int argc, t_atom*argv)
     }
   /* fallthrough */
   default:
-    pd_error(0, "Bad arguments for [z~]: must be nought or initial delay [in samples]");
+    pd_error(0,
+             "Bad arguments for [z~]: must be nought or initial delay [in samples]");
     return 0;
   }
 
@@ -149,7 +150,7 @@ static void zdel_helper(void)
 ZEXY_SETUP void z_tilde_setup(void)
 {
   zNdelay_class = zexy_new("z~",
-                           zNdelay_new, zNdelay_free, t_zNdelay, 0, "*");
+                           zNdelay_new, zNdelay_free, t_zNdelay, CLASS_DEFAULT, "*");
   zexy_addmethod(zNdelay_class, (t_method)nullfn, "signal", "");
   zexy_addmethod(zNdelay_class, (t_method)zNdelay_dsp, "dsp", "!");
 
